@@ -1,6 +1,8 @@
 /*
  * Lepton EDA command-line utility
  * Copyright (C) 2012 Peter Brett <peter@peter-b.co.uk>
+ * Copyright (C) 2014-2016 gEDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -961,7 +963,7 @@ export_usage (void)
 {
   printf (_("Usage: lepton-cli export [OPTION ...] -o OUTPUT [--] FILE ...\n"
 "\n"
-"Export gEDA files in various image formats.\n"
+"Export Lepton EDA files in various image formats.\n"
 "\n"
 "  -f, --format=TYPE      output format (normally autodetected)\n"
 "  -o, --output=OUTPUT    output filename\n"
@@ -1157,6 +1159,8 @@ export_command_line (int argc, char * const *argv)
 int
 cmd_export (int argc, char **argv)
 {
+  set_guile_compiled_path();
+
   scm_boot_guile (argc, argv, cmd_export_impl, NULL); /* Doesn't return */
   return 0;
 }
