@@ -1,7 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library
+/* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1157,7 +1157,7 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
         if (o_current->picture == NULL) {
           return 0;
         }
-        geda_picture_object_calculate_bounds (toplevel, o_current, &bounds);
+        geda_picture_object_calculate_bounds (o_current, &bounds);
         break;
 
       case(OBJ_CIRCLE):
