@@ -1,7 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library
+/* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -295,7 +295,7 @@ OBJECT *o_picture_new (TOPLEVEL *toplevel,
   picture->file_content = NULL;
   picture->file_length = 0;
 
-  picture->ratio = abs ((double) (x1 - x2) / (y1 - y2));
+  picture->ratio = fabs ((double) (x1 - x2) / (y1 - y2));
   picture->filename = g_strdup (filename);
   picture->angle = angle;
   picture->mirrored = mirrored;
@@ -336,13 +336,11 @@ OBJECT *o_picture_new (TOPLEVEL *toplevel,
  *
  *  On failure, this function sets the bounds to empty.
  *
- *  \param [in]  toplevel  Unused
  *  \param [in]  object    Picture OBJECT to read coordinates from.
  *  \param [out] bounds    The bounds of the picture
  */
 void
-geda_picture_object_calculate_bounds (TOPLEVEL *toplevel,
-                                      const OBJECT *object,
+geda_picture_object_calculate_bounds (const OBJECT *object,
                                       GedaBounds *bounds)
 {
   geda_bounds_init (bounds);
@@ -392,12 +390,11 @@ geda_picture_object_get_position (const GedaObject *object, gint *x, gint *y)
  * Returns the width/height ratio of picture \a object, taking the
  * image rotation into account.
  *
- * \param toplevel  The current #TOPLEVEL.
  * \param object    Picture #OBJECT to inspect.
  * \return width/height ratio for \a object.
  */
 double
-o_picture_get_ratio (TOPLEVEL *toplevel, OBJECT *object)
+o_picture_get_ratio (OBJECT *object)
 {
   g_return_val_if_fail (object != NULL, 1);
   g_return_val_if_fail (object->picture != NULL, 1);
@@ -445,7 +442,7 @@ void o_picture_modify(TOPLEVEL *toplevel, OBJECT *object,
                       int x, int y, int whichone)
 {
   int tmp;
-  double ratio = o_picture_get_ratio (toplevel, object);
+  double ratio = o_picture_get_ratio (object);
 
   o_emit_pre_change_notify (toplevel, object);
 
@@ -1013,7 +1010,6 @@ o_picture_set_from_file (TOPLEVEL *toplevel, OBJECT *object,
  * \par Function Description
  * Returns the filename associated with the picture \a object.
  *
- * \param toplevel The current #TOPLEVEL.
  * \param object   The picture #OBJECT to inspect.
  * \return the filename associated with \a object.
  */
