@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;;; Copyright (C) 2017-2019 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -25,36 +25,37 @@
   #:use-module ((ice-9 rdelim) #:select (read-string) #:prefix rdelim:)
   #:use-module (ice-9 ftw)
   #:use-module (ice-9 i18n)
+  #:use-module (ice-9 regex)
   #:use-module (netlist option)
-  #:use-module (netlist package)
+  #:use-module (netlist schematic-component)
   #:use-module (netlist sort)
   #:use-module (netlist attrib compare)
-  #:use-module (geda library)
   #:use-module (geda page)
   #:use-module (geda deprecated)
   #:use-module (geda log)
   #:use-module (geda repl)
+  #:use-module (lepton library)
   #:use-module (lepton version)
   #:use-module (netlist core gettext)
   #:use-module (netlist config)
+  #:use-module (netlist deprecated)
   #:use-module (netlist error)
   #:use-module (netlist schematic)
   #:use-module (netlist package-pin)
   #:use-module (netlist pin-net)
+  #:use-module (netlist schematic toplevel)
   #:use-module (netlist verbose)
   #:use-module ((netlist rename) #:select (get-rename-list))
 
   #:export (lepton-netlist-version
             main
-            set-toplevel-schematic!
-            toplevel-schematic
             calling-flag?
             get-device
+            get-connections
             get-all-connections
             get-all-package-attributes
             get-component-text
             get-nets
-            get-pins
             get-pins-nets
             message
             package-pin-netname
@@ -75,14 +76,20 @@
             gnetlist:wrap
             known?
             unknown?
-            pair<?
-            ;; Legacy variables
-            packages
-            all-unique-nets
-            all-nets
-            all-pins)
+            pair<?)
 
-  #:re-export (source-library))
+  #:re-export (;; (lepton library)
+               source-library
+               ;; (netlist deprecated)
+               ;; deprecated procedures
+               get-pins
+               gnetlist:get-pins
+               ;; deprecated variables
+               non-unique-packages
+               packages
+               all-unique-nets
+               all-nets
+               all-pins))
 
 
 (define* (lepton-netlist-version #:optional output-to-log? exit?)
@@ -94,7 +101,7 @@ to current standard output port and exit with exit status 0."
   (define version-msg "Lepton EDA/lepton-netlist ~A~A.~A (git: ~A)\n")
 
   (define copyright-msg (_ "Copyright (C) 1998-2016 gEDA developers
-Copyright (C) 2017-2018 Lepton EDA Contributors
+Copyright (C) 2017-2019 Lepton EDA Contributors
 This is free software, and you are welcome to redistribute it under
 certain conditions. For details, see the file `COPYING', which is
 included in the Lepton EDA distribution.
@@ -160,23 +167,6 @@ code should use `gnetlist:get-backend-arguments' directly."
 
 ;; Support functions
 
-;;; Returns the list of attached attributes of PACKAGE with given
-;;; NAME which must be a symbol (not string). If no attached
-;;; attributes found, returns the list of inherited attributes
-;;; with given NAME. If neither attached nor inherited attributes
-;;; have been found, returns #f.
-(define (package-attributes package name)
-  (or (assq-ref (package-attribs package) name)
-      (assq-ref (package-iattribs package) name)))
-
-;;; Returns first attached attribute of PACKAGE with given NAME
-;;; which must be a symbol (not string). If no attached attribute
-;;; found, returns first inherited attribute with NAME. If neither
-;;; attached nor inherited attribute found, returns #f.
-(define (package-attribute package name)
-  (and=> (package-attributes package name) car))
-
-
 ;;; Default resolver: Returns the first valid (non-#F) value from
 ;;; VALUES, or #F, if there is no valid attribute value. If any
 ;;; other valid value in the list is different, yields a warning
@@ -211,15 +201,16 @@ associated with the first symbol instance)."
   (define sname (string->symbol attribute-name))
 
   (define (found-package? package)
-    (let ((name (package-refdes package)))
+    (let ((name (schematic-component-refdes package)))
       (and name
            (string=? name package-name)
            package)))
 
   (map
    (lambda (package)
-     (package-attribute package sname))
-   (filter-map found-package? (schematic-netlist toplevel-schematic))))
+     (schematic-component-attribute package sname))
+   (filter-map found-package?
+               (schematic-components (toplevel-schematic)))))
 
 
 (define (gnetlist:get-package-attribute refdes name)
@@ -349,54 +340,62 @@ REFDES. As a result, slots may be repeated in the returned list."
   (display output-string message-port)
   )
 
-(define toplevel-schematic #f)
-
 
 ;;; Helper function for sorting connections.
 (define (pair<? a b)
-  (or (refdes<? (car a) (car b))
-      (and (string=? (car a) (car b))
-           (refdes<? (cdr a) (cdr b)))))
+  (let ((refdes-a (schematic-component-refdes->string (car a)))
+        (refdes-b (schematic-component-refdes->string (car b)))
+        (pin-a (cdr a))
+        (pin-b (cdr b)))
+    (or (refdes<? refdes-a refdes-b)
+        (and (string=? refdes-a refdes-b)
+             (refdes<? pin-a pin-b)))))
 
 
 
-(define (get-all-connections netname)
+(define (get-connections netname schematic)
   "Returns all connections in the form of ((refdes pin) ...) for
-NETNAME."
+NETNAME in SCHEMATIC."
   (define (found? x)
     (and x
          (string=? x netname)))
 
-  (define netlist
-    (schematic-netlist toplevel-schematic))
+  (define netlist (schematic-components schematic))
 
   (define non-graphical-refdeses
-    (filter-map package-refdes netlist))
+    (filter-map schematic-component-refdes netlist))
 
-  (define (non-graphical? refdes)
-    (member refdes non-graphical-refdeses))
+  (define (refdes->string refdes)
+    (let ((refdes (schematic-component-refdes->string refdes)))
+      (and (member refdes non-graphical-refdeses)
+           refdes)))
 
   (define (get-found-pin-connections pin)
     (if (found? (package-pin-name pin))
         (filter-map
-         (lambda (net) (let ((package (pin-net-connection-package net))
-                        (pinnumber (pin-net-connection-pinnumber net)))
-                    (and package
-                         (non-graphical? package)
-                         pinnumber
-                         (cons package pinnumber))))
+         (lambda (net)
+           (let ((refdes (refdes->string (pin-net-connection-package net)))
+                 (pinnumber (pin-net-connection-pinnumber net)))
+             (and refdes
+                  pinnumber
+                  (cons refdes pinnumber))))
          (package-pin-nets pin))
         '()))
 
   (define (get-netlist-connections netlist)
     (append-map
      (lambda (package)
-       (append-map get-found-pin-connections (package-pins package)))
+       (append-map get-found-pin-connections (schematic-component-pins package)))
      netlist))
 
   (sort-remove-duplicates (get-netlist-connections netlist)
                           pair<?))
 
+(define (get-all-connections netname)
+  "Returns all connections in the form of ((refdes pin) ...) for
+NETNAME."
+  (get-connections netname (toplevel-schematic)))
+
 
 (define (get-pins-nets package)
   "Returns a list of pairs (pin-name . net-name) where net-name is
@@ -415,32 +414,17 @@ PACKAGE."
            (cons pin-number pin-name))))
 
   (define (get-pin-netname-list package)
-     (if (found? (package-refdes package))
-         (filter-map get-pin-netname-pair (package-pins package))
+     (if (found? (schematic-component-refdes package))
+         (filter-map get-pin-netname-pair (schematic-component-pins package))
          '()))
 
   ;; Currently, netlist can contain many `packages' with the same
   ;; name, so we have to deal with this.
   (let ((result-list (append-map get-pin-netname-list
-                                 (schematic-netlist toplevel-schematic))))
+                                 (schematic-components (toplevel-schematic)))))
     (sort-remove-duplicates result-list pair<?)))
 
 
-(define (get-pins refdes)
-  (define (found? x)
-    (and x
-         (string=? x refdes)))
-
-  (sort-remove-duplicates
-   (append-map
-    (lambda (package)
-      (if (found? (package-refdes package))
-          (filter-map package-pin-number (package-pins package))
-          '()))
-    (schematic-netlist toplevel-schematic))
-   refdes<?))
-
-
 ;;; This procedure is buggy in the same way as gnetlist:get-nets.
 ;;; It should first search for netname, and then get all
 ;;; package-pin pairs by that netname.
@@ -482,12 +466,12 @@ PACKAGE."
   (define (lookup-through-netlist netlist)
     (append-map
      (lambda (package)
-       (if (found-package? (package-refdes package))
-           (lookup-through-pins (package-pins package))
+       (if (found-package? (schematic-component-refdes package))
+           (lookup-through-pins (schematic-component-pins package))
            '()))
      netlist))
 
-  (let ((found (lookup-through-netlist (schematic-netlist toplevel-schematic))))
+  (let ((found (lookup-through-netlist (schematic-components (toplevel-schematic)))))
     (match found
       (() '("ERROR_INVALID_PIN"))
       (((netname . rest) ...)
@@ -499,44 +483,38 @@ PACKAGE."
   (or (assoc-ref (get-pins-nets package) pinnumber)
       "ERROR_INVALID_PIN"))
 
-;;; Backward compatibility variables and procedures
-(define packages #f)
-(define all-unique-nets #f)
-(define all-nets #f)
-(define all-pins #f)
 
 (define (gnetlist:get-toplevel-attribute attrib)
-  (or (assq-ref (schematic-toplevel-attribs toplevel-schematic)
+  (or (assq-ref (schematic-toplevel-attribs (toplevel-schematic))
                 (string->symbol attrib))
       "not found"))
 
-(define gnetlist:get-pins get-pins)
 (define gnetlist:get-all-package-attributes get-all-package-attributes)
 (define gnetlist:get-nets get-nets)
 (define gnetlist:get-pins-nets get-pins-nets)
 (define (gnetlist:get-verbosity)
-  (if (gnetlist-option-ref 'verbose)
+  (if (netlist-option-ref 'verbose)
       1
-      (if (gnetlist-option-ref 'quiet)
+      (if (netlist-option-ref 'quiet)
           -1
           0)))
 (define (gnetlist:get-input-files)
-  (gnetlist-option-ref '()))
+  (netlist-option-ref '()))
 (define (gnetlist:get-command-line)
   (string-join (command-line) " "))
 (define (gnetlist:get-packages level)
-  (schematic-package-names toplevel-schematic))
+  (schematic-package-names (toplevel-schematic)))
 (define (gnetlist:get-non-unique-packages level)
-  (schematic-non-unique-package-names toplevel-schematic))
+  (schematic-non-unique-package-names (toplevel-schematic)))
 (define (gnetlist:get-all-unique-nets level)
-  (schematic-nets toplevel-schematic))
+  (schematic-nets (toplevel-schematic)))
 (define (gnetlist:get-all-nets level)
-  (schematic-non-unique-nets toplevel-schematic))
+  (schematic-non-unique-nets (toplevel-schematic)))
 (define (gnetlist:get-all-connections netname)
   (map (lambda (pair) (list (car pair) (cdr pair)))
        (get-all-connections netname)))
 (define (gnetlist:get-backend-arguments)
-  (gnetlist-option-ref 'backend-option))
+  (netlist-option-ref 'backend-option))
 (define (gnetlist:get-renamed-nets level)
   (map
    (lambda (rename)
@@ -685,17 +663,17 @@ other limitations imposed by this netlist format.
                pin
                (find-pin-by-attrib (cdr pins) name value)))))
 
-  (let loop ((netlist (schematic-netlist toplevel-schematic)))
+  (let loop ((netlist (schematic-components (toplevel-schematic))))
     (if (null? netlist)
         "unknown"
-        (or (and (found-refdes? (package-refdes (car netlist)))
-                 (let ((pin (find-pin-by-attrib (package-pins (car netlist))
+        (or (and (found-refdes? (schematic-component-refdes (car netlist)))
+                 (let ((pin (find-pin-by-attrib (schematic-component-pins (car netlist))
                                                 (string->symbol pin-attrib-name)
                                                 pin-attrib-value)))
                    (if pin
                        (assq-ref (package-pin-attribs pin)
                                  (string->symbol name))
-                       (and func (func (package-pins (car netlist))
+                       (and func (func (schematic-component-pins (car netlist))
                                        name
                                        pin-attrib-value)))))
             (loop (cdr netlist))))))
@@ -764,20 +742,18 @@ other limitations imposed by this netlist format.
     (and netname
         (append-map
          (lambda (package)
-           (if (and (have-netname? (package-pins package))
-                    (have-attrib? (package-attribs package) in-attrib))
-               (assq-ref (package-attribs package) out-attrib)
+           (if (and (have-netname? (schematic-component-pins package))
+                    (have-attrib? (schematic-component-attribs package) in-attrib))
+               (assq-ref (schematic-component-attribs package) out-attrib)
                '()))
-         (schematic-graphicals toplevel-schematic)))))
+         (schematic-graphicals (toplevel-schematic))))))
 
 (define (get-output-filename)
   ;; Name is file name or "-" which means stdout.
-  (let ((name (gnetlist-option-ref 'output)))
+  (let ((name (netlist-option-ref 'output)))
     (and (not (string=? name "-"))
          name)))
 
-(define quiet-mode (gnetlist-option-ref 'quiet))
-
 ;;; List of processed rc directories.
 (define %rc-dirs (make-hash-table))
 
@@ -791,13 +767,6 @@ other limitations imposed by this netlist format.
       (hash-set! %rc-dirs cwd cwd)
       (chdir cwd))))
 
-;;; Reads file NAME and outputs a page named NAME
-(define (file->page name)
-  (with-input-from-file name
-    (lambda ()
-      (when (not quiet-mode)
-        (log! 'message (_ "Loading schematic ~S\n") name))
-      (string->page name (rdelim:read-string)))))
 
 ;;; Prints a list of available backends.
 (define (gnetlist-backends)
@@ -841,13 +810,13 @@ General options:
   -o FILE         Filename for netlist data output.
   -L DIR          Add DIR to Scheme search path.
   -g BACKEND      Specify netlist backend to use.
+  -f FILE         Specify path to netlist backend file to use.
   -O STRING       Pass an option string to backend.
   -l FILE         Load Scheme file before loading backend.
   -m FILE         Load Scheme file after loading backend.
   -c EXPR         Evaluate Scheme expression at startup.
   -i              Enter interactive Scheme REPL after loading.
   --list-backends Print a list of available netlist backends.
-  -w              Do not display warning about missing configuration files.
   -h, --help      Help; this message.
   -V, --version   Show version information.
   --              Treat all remaining arguments as filenames.
@@ -859,19 +828,13 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
   (primitive-exit 0))
 
 
-(define (set-toplevel-schematic! files netlist-mode)
+;;; Set lepton-netlist toplevel schematic based on schematic FILES
+;;; and NETLIST-MODE which must be either "'geda", or "'spice".
+(define (set-ln-toplevel-schematic! files netlist-mode)
   (and (eq? netlist-mode 'spice)
        (set! get-uref get-spice-refdes))
   (for-each process-gafrc files)
-  (set! toplevel-schematic
-        (make-toplevel-schematic (map file->page files)
-                                 netlist-mode))
-  ;; Backward compatibility variables. Don't use them in your code!!!
-  (set! packages (schematic-package-names toplevel-schematic))
-  (set! all-unique-nets (schematic-nets toplevel-schematic))
-  (set! all-nets (schematic-non-unique-nets toplevel-schematic))
-  (set! all-pins (map gnetlist:get-pins packages))
-  toplevel-schematic)
+  (set-toplevel-schematic! (make-toplevel-schematic files netlist-mode)))
 
 
 (define (catch-handler tag . args)
@@ -898,19 +861,21 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
 ( let
   (
   ( output-filename   (get-output-filename) )
-  ( files             (gnetlist-option-ref '()) )            ; schematics
-  ( opt-backend       (gnetlist-option-ref 'backend) )       ; -g
-  ( opt-interactive   (gnetlist-option-ref 'interactive) )   ; -i
-  ( opt-verbose       (gnetlist-option-ref 'verbose) )       ; --verbose (-v)
-  ( opt-code-to-eval  (gnetlist-option-ref 'eval-code) )     ; -c
-  ( opt-help          (gnetlist-option-ref 'help) )          ; --help (-h)
-  ( opt-version       (gnetlist-option-ref 'version) )       ; --version (-V)
-  ( opt-list-backends (gnetlist-option-ref 'list-backends) ) ; --list-backends
-  ( opt-pre-load      (gnetlist-option-ref 'pre-load) )      ; -l
-  ( opt-post-load     (gnetlist-option-ref 'post-load) )     ; -m
+  ( files             (netlist-option-ref '()) )            ; schematics
+  ( opt-backend       (netlist-option-ref 'backend) )       ; -g
+  ( opt-file-backend  (netlist-option-ref 'file-backend) )  ; -f
+  ( opt-interactive   (netlist-option-ref 'interactive) )   ; -i
+  ( opt-verbose       (netlist-option-ref 'verbose) )       ; --verbose (-v)
+  ( opt-code-to-eval  (netlist-option-ref 'eval-code) )     ; -c
+  ( opt-help          (netlist-option-ref 'help) )          ; --help (-h)
+  ( opt-version       (netlist-option-ref 'version) )       ; --version (-V)
+  ( opt-list-backends (netlist-option-ref 'list-backends) ) ; --list-backends
+  ( opt-pre-load      (netlist-option-ref 'pre-load) )      ; -l
+  ( opt-post-load     (netlist-option-ref 'post-load) )     ; -m
   ( netlist-mode      'geda )
   ( backend-path      #f )
   ( schematic         #f )
+  ( backend-proc-name #f )
   )
 
   ; local functions:
@@ -931,6 +896,28 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
                      backend (car (program-arguments)))
   )
 
+  ( define ( error-backend-file-name bname )
+    (netlist-error 1 (_ "Can't load backend file ~S.\n~
+                         Backend files are expected to have names like \"gnet-NAME.scm\"\n~
+                         and contain entry point function NAME (where NAME is the backend's name).\n")
+                     bname)
+  )
+
+  ( define ( get-backend-proc-name filename )
+  ( let*
+    (
+    ( bname (basename filename) )
+    ( re    (string-match "^gnet-(.*).scm$" bname) )
+    )
+
+    ; return:
+    ( if re
+        ( match:substring re 1 )          ; if
+        ( error-backend-file-name bname ) ; else
+    )
+  )
+  )
+
 
   ; Parse configuration:
   ;
@@ -947,7 +934,7 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
   ( unless ( null? opt-code-to-eval )
     ( catch #t
       ( lambda()
-        ( apply eval-string opt-code-to-eval )
+        (for-each eval-string opt-code-to-eval)
       )
       ( lambda( tag . args )
         ( catch-handler tag args )
@@ -989,12 +976,23 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
     )
   )
 
-  ; Load backend:
+  ; Backend specified by name:
   ;
   ( when opt-backend
     ( set! backend-path ( %search-load-path (format #f "gnet-~A.scm" opt-backend) ) )
+    ( set! backend-proc-name opt-backend )
   )
 
+  ; Backend specified by file name:
+  ;
+  ( when opt-file-backend
+    ( set! backend-path opt-file-backend )
+    ( set! backend-proc-name (get-backend-proc-name backend-path) )
+  )
+
+
+  ; Load backend file:
+  ;
   ( when backend-path
     ( catch #t
       ( lambda()
@@ -1025,30 +1023,30 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
     ( print-gnetlist-config )
   )
 
-  ; Neither backend (-g), nor interactive mode (-i) specified:
+  ; Neither backend (-g or -f), nor interactive mode (-i) specified:
   ;
-  ( unless ( or opt-backend opt-interactive )
+  ( unless ( or opt-backend opt-file-backend opt-interactive )
     ( error-no-backend )
   )
 
   ; This sets [toplevel-schematic] global variable:
   ;
-  ( set! schematic (set-toplevel-schematic! files netlist-mode) )
+  ( set! schematic (set-ln-toplevel-schematic! files netlist-mode) )
 
   ; Verbose mode (-v): print internal netlist representation:
   ;
   ( when opt-verbose
-    ( verbose-print-netlist (schematic-netlist schematic) )
+    ( verbose-print-netlist (schematic-components schematic) )
   )
 
 
   ; Do actual work:
   ;
   ( if opt-interactive
-    ( lepton-repl )   ; if
-    ( if backend-path ; else
-      ( run-backend opt-backend output-filename ) ; if
-      ( error-backend-not-found opt-backend )     ; else
+    ( lepton-repl )                             ; if
+    ( if ( and backend-path backend-proc-name ) ; else
+      ( run-backend backend-proc-name output-filename ) ; if
+      ( error-backend-not-found opt-backend )           ; else
     )
   )
 
