@@ -1,6 +1,6 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 2016-2017 gEDA Contributors
-;;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;;; Copyright (C) 2017-2019 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -22,23 +22,24 @@
   ; Import C procedures and variables
   #:use-module (netlist core gettext)
 
-  #:use-module ((ice-9 rdelim)
-                #:select (read-string)
-                #:prefix rdelim:)
+  #:use-module ((ice-9 match))
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:use-module (geda attrib)
   #:use-module (geda object)
-  #:use-module (geda library)
   #:use-module (geda log)
   #:use-module (geda page)
+  #:use-module (lepton library)
   #:use-module (netlist config)
   #:use-module (netlist hierarchy)
   #:use-module (netlist rename)
   #:use-module (netlist net)
-  #:use-module (netlist package)
+  #:use-module (netlist option)
   #:use-module (netlist package-pin)
+  #:use-module (netlist page)
   #:use-module (netlist pin-net)
+  #:use-module (netlist schematic-component)
+  #:use-module (netlist schematic-connection)
   #:use-module (netlist verbose)
   #:use-module (symbol check net-attrib)
 
@@ -169,7 +170,15 @@
          (or (hash-ref %netnames (pin-net-id (car nets)))
              (search-in-hash-table (cdr nets)))))
 
-(define (object-pins object tag netlist-mode)
+(define (get-package-pin-connection pin-object connections)
+  (let loop ((groups connections))
+    (and (not (null? groups))
+         (let ((group (car groups)))
+           (or (and (member pin-object (schematic-connection-objects group)) group)
+               (loop (cdr groups)))))))
+
+
+(define (object-pins object tag netlist-mode connections)
   (define (make-pin-attrib-list object)
     (define (add-attrib attrib)
       (cons (string->symbol (attrib-name attrib))
@@ -207,12 +216,12 @@
                  nets))
            (make-package-pin (object-id object)
                              object
-                             'net-pin
                              (assq-ref attribs 'pinnumber)
                              netname
                              (assq-ref attribs 'pinlabel)
                              attribs
-                             nets))))
+                             nets
+                             (get-package-pin-connection object connections)))))
 
   (filter-map object->package-pin (component-contents object)))
 
@@ -283,44 +292,70 @@
            (object #f)
            (attribs '())
            (nets (list (make-pin-net id net-priority netname refdes pinnumber))))
-      (make-package-pin id object 'net pinnumber netname label attribs nets)))
+      (make-package-pin id object pinnumber netname label attribs nets #f)))
+
+  (define (add-net-power-pin-override pin net-map tag)
+    (define (power-pin? pin)
+      (string=? "pwr" (assq-ref (package-pin-attribs pin) 'pintype)))
+
+    (let ((connection (package-pin-connection pin))
+          (name (create-netattrib (net-map-netname net-map) tag)))
+      (when (power-pin? pin)
+        (set-schematic-connection-override-name!
+         connection
+         (match (schematic-connection-override-name connection)
+           ((? list? x) `(,name . ,x))
+           (#f name)
+           (x `(,name ,x)))))))
 
   (append pin-list
           (filter-map
            (lambda (net-map)
              (let ((pin (pinnumber->pin (net-map-pinnumber net-map) pin-list)))
                (if pin
-                   (update-pin pin net-map id refdes tag)
+                   (begin
+                     (add-net-power-pin-override pin net-map tag)
+                     (update-pin pin net-map id refdes tag))
                    (make-net-map-pin net-map id refdes tag))))
            net-maps)))
 
 
-(define (get-sources inherited-attribs attached-attribs)
+(define (get-sources graphical? inherited-attribs attached-attribs)
   (define (non-null* ls)
     (and (not (null? ls)) ls))
 
+  ;; Given a list of strings, some of which may contain commas,
+  ;; splits comma separated strings and returns the new combined
+  ;; list
   (define (comma-separated->list ls)
     (append-map (lambda (s) (string-split s #\,)) ls))
 
-  (let ((sources
-         (or
-          (non-null* (assq-ref attached-attribs 'source))
-          (non-null* (assq-ref inherited-attribs 'source)))))
-    (and=> sources comma-separated->list)))
-
-
-;;; Reads file NAME and outputs a page named NAME
-(define (file->page name)
-  (with-input-from-file name
-    (lambda () (string->page name (rdelim:read-string)))))
+  (and (not graphical?)
+       (gnetlist-config-ref 'traverse-hierarchy)
+       (let ((sources
+              (or (non-null* (assq-ref attached-attribs 'source))
+                  (non-null* (assq-ref inherited-attribs 'source)))))
+         (and=> sources comma-separated->list))))
 
 (define (hierarchy-down-schematic name)
   (let ((filename (get-source-library-file name)))
     (if filename
-        (file->page filename)
+        (filename->page filename 'new-page)
         (log! 'error (_ "Failed to load subcircuit ~S.") name))))
 
 (define (traverse-page page hierarchy-tag netlist-mode)
+  ;; Get refdes= of OBJECT depending on NETLIST-MODE.
+  (define (get-refdes attribs netlist-mode)
+    (let ((refdes (and=> (assq-ref attribs 'refdes) car)))
+      (case netlist-mode
+        ((spice)
+         (let ((slot (and=> (assq-ref attribs 'slot) car)))
+           (if slot
+               (string-append refdes "." slot)
+               refdes)))
+        ((geda) refdes)
+        (else (error (_ "Netlist mode ~S is not supported.") netlist-mode)))))
+
   ;; Makes attribute list of OBJECT using getter GET-ATTRIBS.
   (define (make-attrib-list get-attribs object)
     (define (add-attrib ls attrib)
@@ -351,56 +386,68 @@
                (page-filename (object-page object)))
          "U?"))
 
-  (define (source-netlist filename refdes)
-    (log! 'message (_ "Going to traverse source ~S") filename)
-    (traverse-page (hierarchy-down-schematic filename)
-                   refdes
-                   netlist-mode))
-
-  (define (traverse-object object)
+  (define (traverse-object object connections)
     (let* ((id (object-id object))
            (inherited-attribs (make-attrib-list inherited-attribs object))
            (attached-attribs (make-attrib-list object-attribs object))
            (net-maps (check-net-maps object))
-           (package (make-package id
-                                  #f   ; get refdes later
-                                  hierarchy-tag
-                                  #f   ; get composite later
-                                  object
-                                  inherited-attribs
-                                  attached-attribs
-                                  '())) ; get pins later
-           (graphical (or (package-graphical? package)
-                          (package-nc? package)))
-           (refdes  (hierarchy-create-refdes (or ((@@ (netlist) get-uref) object)
+           (package (make-schematic-component id
+                                              #f   ; get refdes later
+                                              hierarchy-tag
+                                              #f   ; get sources later
+                                              object
+                                              inherited-attribs
+                                              attached-attribs
+                                              '())) ; get pins later
+           (graphical (or (schematic-component-graphical? package)
+                          (schematic-component-nc? package)))
+           (refdes  (hierarchy-create-refdes (or (get-refdes attached-attribs netlist-mode)
                                                  (refdes-by-net object net-maps graphical))
                                              hierarchy-tag))
-           (sources (get-sources inherited-attribs attached-attribs))
-           (composite? (and (not graphical)
-                            (gnetlist-config-ref 'traverse-hierarchy)
-                            sources
-                            (not (null? sources))))
+           (sources (get-sources graphical
+                                 inherited-attribs
+                                 attached-attribs))
            (pins (net-maps->pins net-maps
                                  id
                                  refdes
                                  hierarchy-tag
-                                 (object-pins object hierarchy-tag netlist-mode))))
-      (set-package-refdes! package refdes)
-      (set-package-composite! package composite?)
-      (set-package-pins! package pins)
-      (cons package
-            (if composite?
-                ;; Traverse underlying schematics.
-                (append-map (cut source-netlist <> refdes) sources)
-                '()))))
+                                 (object-pins object hierarchy-tag netlist-mode connections))))
+      (set-schematic-component-refdes! package refdes)
+      (set-schematic-component-sources! package sources)
+      (set-schematic-component-pins! package pins)
+      package))
 
-  (append-map traverse-object
-              (filter component? (page-contents page))))
+  (when hierarchy-tag
+    (log! 'message (_ "Going to traverse source ~S") (page-filename page)))
 
-(define (traverse-pages pages netlist-mode)
-  (append-map (cut traverse-page <> #f netlist-mode) pages))
+  (let* ((objects (page-contents page))
+         (components (filter component? objects))
+         (connections (make-page-schematic-connections page))
+         (schematic-components (map (cut traverse-object <> connections) components)))
+    schematic-components))
+
+;;; Traverses pages obtained from files defined in the 'source='
+;;; attributes of COMPONENT with respect to HIERARCHY-TAG and
+;;; NETLIST-MODE.
+(define (traverse-component-sources component hierarchy-tag netlist-mode)
+  (let ((hierarchy-tag (schematic-component-refdes component))
+        (source-pages (map hierarchy-down-schematic
+                           (schematic-component-sources component))))
+    (traverse-pages source-pages hierarchy-tag netlist-mode)))
+
+(define (traverse-pages pages hierarchy-tag netlist-mode)
+  (let* ((schematic-components (append-map (cut traverse-page <> hierarchy-tag netlist-mode) pages))
+         (composites (filter schematic-component-sources schematic-components))
+         ;; Traverse underlying schematics.
+         (underlying-components (append-map (cut traverse-component-sources
+                                                 <>
+                                                 hierarchy-tag
+                                                 netlist-mode)
+                                            composites)))
+    (append schematic-components underlying-components)))
 
 (define (traverse toplevel-pages netlist-mode)
   (reset-rename!)
   (rename-all (hierarchy-post-process (traverse-pages toplevel-pages
+                                                      #f ; toplevel hierarchy tag
                                                       netlist-mode))))
