@@ -1,4 +1,5 @@
-/* $Id$ */
+#ifndef LEPTON_PROTOTYPE_H_
+#define LEPTON_PROTOTYPE_H_
 
 /* a_zoom.c */
 void a_zoom(GschemToplevel *w_current, GschemPageView *page_view, int dir, int selected_from);
@@ -16,14 +17,11 @@ void g_init_builtins (void);
 /* g_attrib.c */
 void g_init_attrib ();
 /* g_funcs.c */
-SCM g_funcs_pdf(SCM filename);
-SCM g_funcs_image(SCM filename);
 SCM g_funcs_exit(void);
 SCM g_funcs_log(SCM msg);
 SCM g_funcs_msg(SCM msg);
 SCM g_funcs_confirm(SCM msg);
 SCM g_funcs_filesel(SCM msg, SCM templ, SCM flags);
-SCM g_funcs_use_rc_values(void);
 /* g_hook.c */
 void g_init_hook ();
 void g_run_hook_object (GschemToplevel *w_current, const char *name, OBJECT *obj);
@@ -165,13 +163,9 @@ SCM g_rc_embed_components(SCM mode);
 SCM g_rc_text_size(SCM size);
 SCM g_rc_text_caps_style(SCM mode);
 SCM g_rc_snap_size(SCM size);
-SCM g_rc_logging_destination(SCM mode);
 SCM g_rc_attribute_name(SCM path);
 SCM g_rc_scrollbars(SCM mode);
-SCM g_rc_image_color(SCM mode);
-SCM g_rc_image_size(SCM width, SCM height);
 SCM g_rc_log_window(SCM mode);
-SCM g_rc_log_window_type(SCM mode);
 SCM g_rc_third_button(SCM mode);
 SCM g_rc_third_button_cancel(SCM mode);
 SCM g_rc_middle_button(SCM mode);
@@ -180,7 +174,6 @@ SCM g_rc_net_consolidate(SCM mode);
 SCM g_rc_file_preview(SCM mode);
 SCM g_rc_enforce_hierarchy(SCM mode);
 SCM g_rc_fast_mousepan(SCM mode);
-SCM g_rc_raise_dialog_boxes_on_expose(SCM mode);
 SCM g_rc_continue_component_place(SCM mode);
 SCM g_rc_undo_levels(SCM levels);
 SCM g_rc_undo_control(SCM mode);
@@ -190,7 +183,6 @@ SCM g_rc_draw_grips(SCM mode);
 SCM g_rc_netconn_rubberband(SCM mode);
 SCM g_rc_magnetic_net_mode(SCM mode);
 SCM g_rc_add_menu(SCM menu_name, SCM menu_items);
-SCM g_rc_window_size(SCM width, SCM height);
 SCM g_rc_warp_cursor(SCM mode);
 SCM g_rc_toolbars(SCM mode);
 SCM g_rc_handleboxes(SCM mode);
@@ -203,7 +195,6 @@ SCM g_rc_dots_grid_dot_size(SCM dotsize);
 SCM g_rc_dots_grid_mode(SCM mode);
 SCM g_rc_dots_grid_fixed_threshold(SCM spacing);
 SCM g_rc_mesh_grid_display_threshold(SCM spacing);
-SCM g_rc_add_attribute_offset(SCM offset);
 SCM g_rc_auto_save_interval(SCM seconds);
 SCM g_rc_mousepan_gain(SCM mode);
 SCM g_rc_keyboardpan_gain(SCM mode);
@@ -239,10 +230,9 @@ void i_action_update_status(GschemToplevel *w_current,gboolean inside_action);
 void i_show_state(GschemToplevel *w_current, const char *message);
 void i_set_state(GschemToplevel *w_current, enum x_states newstate);
 void i_set_state_msg(GschemToplevel *w_current, enum x_states newstate, const char *message);
-void i_update_middle_button (GschemToplevel *w_current, i_callback_func func, const char *string);
 void i_update_toolbar(GschemToplevel *w_current);
 void i_update_menus(GschemToplevel *w_current);
-void i_set_filename(GschemToplevel *w_current, const gchar *string, const gchar *changed);
+void i_set_filename(GschemToplevel *w_current, const gchar *filename, gboolean changed);
 void i_update_grid_info(GschemToplevel *w_current);
 void i_update_grid_info_callback (GschemPageView *view, GschemToplevel *w_current);
 void i_update_net_options_status (GschemToplevel* w_current);
@@ -355,8 +345,6 @@ void i_callback_add_pin(gpointer data, guint callback_action, GtkWidget *widget)
 void i_callback_hierarchy_down_schematic(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_hierarchy_down_symbol(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_hierarchy_up(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_attributes_attach(gpointer data, guint callback_action, GtkWidget *widget);
-void i_callback_attributes_detach(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_attributes_show_name(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_attributes_show_value(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_attributes_show_both(gpointer data, guint callback_action, GtkWidget *widget);
@@ -380,8 +368,7 @@ gboolean i_callback_close_wm(GtkWidget *widget, GdkEvent *event, gpointer data);
 /* i_vars.c */
 void i_vars_set(GschemToplevel *w_current);
 void i_vars_freenames();
-void i_vars_init_gschem_defaults (void);
-void i_vars_atexit_save_user_config (gpointer user_data);
+void i_vars_init_defaults (void);
 void i_vars_atexit_save_cache_config (gpointer user_data);
  /* m_basic.c */
 int snap_grid(GschemToplevel *w_current, int input);
@@ -637,7 +624,6 @@ void coord_display_update(GschemToplevel *w_current, int x, int y);
 void coord_dialog(GschemToplevel *w_current, int x, int y);
 char *index2functionstring(int index);
 void x_dialog_hotkeys(GschemToplevel *w_current);
-void x_dialog_raise_all(GschemToplevel *w_current);
 
 void generic_msg_dialog(const char *);
 int generic_confirm_dialog(const char *);
@@ -652,7 +638,6 @@ gboolean x_dialog_close_window (GschemToplevel *w_current);
 int x_dialog_validate_attribute(GtkWindow* parent, char *attribute);
 /* x_event.c */
 gint x_event_expose(GschemPageView *widget, GdkEventExpose *event, GschemToplevel *w_current);
-gint x_event_raise_dialog_boxes (GschemPageView *view, GdkEventExpose *event, GschemToplevel *w_current);
 gint x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemToplevel *w_current);
 gint x_event_button_released(GschemPageView *page_view, GdkEventButton *event, GschemToplevel *w_current);
 gint x_event_motion(GschemPageView *page_view, GdkEventMotion *event, GschemToplevel *w_current);
@@ -667,7 +652,7 @@ void x_compselect_open (GschemToplevel *w_current);
 void x_compselect_deselect (GschemToplevel *w_current);
 /* x_fileselect.c */
 void x_fileselect_open(GschemToplevel *w_current);
-void x_fileselect_save(GschemToplevel *w_current);
+gboolean x_fileselect_save(GschemToplevel *w_current, PAGE* page, gboolean* result);
 int x_fileselect_load_backup(void *user_data, GString *message);
 /* x_fstylecb.c */
 GtkWidget* x_fstylecb_new ();
@@ -678,16 +663,15 @@ void x_grid_draw_region(GschemToplevel *w_current, cairo_t *cr, int x, int y, in
 int x_grid_query_drawn_spacing(GschemToplevel *w_current);
 /* x_image.c */
 void x_image_lowlevel(GschemToplevel *w_current, const char* filename,
-                      int desired_width, int desired_height, const char *filetype);
+                      int desired_width, int desired_height, const char *filetype, gboolean is_color);
 void x_image_setup(GschemToplevel *w_current);
-GdkPixbuf *x_image_get_pixbuf (GschemToplevel *w_current, int width, int height);
+GdkPixbuf *x_image_get_pixbuf (GschemToplevel *w_current, int width, int height, gboolean is_color);
 /* x_integerls.c */
 GtkListStore* x_integerls_new ();
 GtkListStore* x_integerls_new_with_values (const char *value[], int count);
 void x_integerls_add_value (GtkListStore *store, const char *value);
 int x_integerls_get_value_column ();
 /* gschem_log_widget.c */
-void x_log_open (GschemToplevel *w_current);
 void x_log_message (const gchar *log_domain,
                     GLogLevelFlags log_level,
                     const gchar *message);
@@ -712,15 +696,9 @@ void x_menu_attach_recent_files_submenu(GschemToplevel *w_current);
 void x_multiattrib_open (GschemToplevel *w_current);
 void x_multiattrib_close (GschemToplevel *w_current);
 void x_multiattrib_update (GschemToplevel *w_current);
-/* x_multimulti.c */
-/* x_pagesel.c */
-void x_pagesel_open (GschemToplevel *w_current);
-void x_pagesel_close (GschemToplevel *w_current);
-void x_pagesel_update (GschemToplevel *w_current);
-/* x_preview.c */
 /* x_print.c */
 gboolean x_print_export_pdf_page (GschemToplevel *w_current, const gchar *filename);
-gboolean x_print_export_pdf (GschemToplevel *w_current, const gchar *filename);
+gboolean x_print_export_pdf (GschemToplevel *w_current, const gchar *filename, gboolean is_color);
 void x_print (GschemToplevel *w_current);
 /* x_rc.c */
 void x_rc_parse_gschem (TOPLEVEL *toplevel, const gchar *rcfile);
@@ -758,6 +736,7 @@ void x_window_init_icons (void);
 GschemToplevel* x_window_new (TOPLEVEL *toplevel);
 void x_window_select_object (GschemFindTextState *state, OBJECT *object, GschemToplevel *w_current);
 void x_window_setup_scrolling (GschemToplevel *w_current, GtkWidget *scrolled);
+gboolean x_window_untitled_page (PAGE* page);
 
 /* x_widgets.c */
 gboolean x_widgets_use_docks();
@@ -770,6 +749,7 @@ void x_widgets_show_log (GschemToplevel* w_current);
 void x_widgets_show_find_text_state (GschemToplevel* w_current);
 void x_widgets_show_color_edit (GschemToplevel* w_current);
 void x_widgets_show_font_select (GschemToplevel* w_current);
+void x_widgets_show_page_select (GschemToplevel* w_current);
 
 /* x_tabs.c */
 gboolean x_tabs_enabled();
@@ -789,3 +769,6 @@ void x_tabs_dbg_pages_dump (GschemToplevel* w_current);
 /* color_edit_widget.c */
 void color_edit_widget_update (GschemToplevel* w_current);
 
+
+#endif /* LEPTON_PROTOTYPE_H_ */
+
