@@ -2,7 +2,7 @@
 ;; Scheme API
 ;; Copyright (C) 2013 Peter Brett <peter@peter-b.co.uk>
 ;; Copyright (C) 2013-2015 gEDA Contributors
-;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;; Copyright (C) 2017-2019 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -22,6 +22,11 @@
 (define-module (gschem builtins)
   #:use-module (geda object)
   #:use-module (geda repl)
+  #:use-module (geda page)
+  #:use-module (geda attrib)
+  #:use-module (geda log)
+  #:use-module (gschem hook)
+  #:use-module (schematic undo)
   #:use-module (gschem core gettext)
   #:use-module (gschem core builtins)
   #:use-module (gschem action)
@@ -31,8 +36,6 @@
   #:use-module (gschem window)
   #:use-module (srfi srfi-1))
 
-(or (defined? 'define-syntax)
-    (use-modules (ice-9 syncase)))
 
 (define-syntax define-action-public
   (syntax-rules ()
@@ -309,11 +312,127 @@
 ;; -------------------------------------------------------------------
 ;;;; Attribute actions
 
-(define-action-public (&attributes-attach #:label (_ "Attach Attributes") #:icon "attribute-attach")
-  (%attributes-attach))
+( define-action-public
+  ( &attributes-attach
+    #:label (_ "Attach Attributes")
+    #:icon  "attribute-attach"
+  )
+
+  ( let*
+    (
+    ( page ( active-page ) )
+    ( sel  ( if page (page-selection page) '() ) )
+    )
+
+    ( define ( can-attach-to? obj )
+      ; return:
+      ( and
+        ( object? obj )
+        ( not (text? obj) )
+      )
+    )
+
+    ( define ( attachable-attr? obj )
+      ; return:
+      ( and
+        ( attribute?    obj )           ; if it's attribute
+        ( text-visible? obj )           ; if it's visible
+        ( not (attrib-attachment obj) ) ; and does not already attached
+      )
+    )
+
+    ( define ( attach-attr obj attr )
+      ( attach-attribs! obj attr )
+      ( log! 'message (_ "Attribute attached: [~a]") (text-string attr) )
+      ( deselect-object! attr )
+    )
+
+
+    ( let*
+      (
+      ( obj   (find   can-attach-to?   sel) )
+      ( attrs (filter attachable-attr? sel) )
+      ( attrs-not-empty ( not (null? attrs) ) )
+      )
+
+      ( when ( and obj attrs-not-empty )
+
+        ( for-each
+        ( lambda( attr )
+          ( attach-attr obj attr )
+        )
+        attrs
+        )
+
+        ( deselect-object! obj )
+
+        ( set-page-dirty! page )
+        ( run-hook attach-attribs-hook attrs )
+        ( undo-save-state )
+
+      ) ; when
+
+      ; return:
+      attrs
+
+    ) ; let
+
+  ) ; let
+
+) ; &attributes-attach action
+
+
+
+( define-action-public
+  (
+    &attributes-detach
+    #:label (_ "Detach Attributes")
+    #:icon "attribute-detach"
+  )
+
+  ( let*
+    (
+    ( page ( active-page ) )
+    ( sel  ( if page (page-selection page) '() ) )
+    )
+
+    ( define ( detachable-attr? obj ) ; predicate
+      ; return:
+      ( and
+        ( attribute?        obj ) ; if it's attribute
+        ( text-visible?     obj ) ; if it's visible
+        ( attrib-attachment obj ) ; and attached to some object
+      )
+    )
+
+    ( define ( detach-attr attr )
+      ( detach-attribs! (attrib-attachment attr) attr )
+      ( log! 'message (_ "Attribute detached: [~a]") (text-string attr) )
+      ( deselect-object! attr )
+    )
+
+
+    ( let
+      (
+      ( attrs (filter detachable-attr? sel) )
+      )
+
+      ( unless (null? attrs)
+        ( for-each detach-attr attrs )
+        ( set-page-dirty! page )
+        ( run-hook detach-attribs-hook attrs )
+        ( undo-save-state )
+      )
+
+      ; return:
+      attrs
+    )
+
+  ) ; let*
+
+) ; &attributes-detach action
+
 
-(define-action-public (&attributes-detach #:label (_ "Detach Attributes") #:icon "attribute-detach")
-  (%attributes-detach))
 
 (define-action-public (&attributes-show-value #:label (_ "Show Attribute Value") #:icon "attribute-show-value")
   (%attributes-show-value))
@@ -390,45 +509,37 @@
 documentation in a browser or PDF viewer. If no documentation can be
 found, shows a dialog with an error message."
 
-  (catch 'misc-error
-
-   (lambda ()
      (let ((component
             (any (lambda (obj) (and (component? obj) obj))
                  (page-selection (active-page)))))
        (and component (show-component-documentation component))))
 
-   (lambda (key subr msg args . rest)
-     ((@@ (guile-user) gschem-msg) (string-append
-                  (_ "Could not show documentation for selected component:\n\n")
-                  (apply format #f msg args))))))
-
 
 (define-action-public
-    (&help-manual #:label (_ "gEDA Manuals") #:icon "help-browser"
-     #:tooltip (_ "View the front page of the gEDA documentation in a browser."))
+    (&help-manual #:label (_ "Lepton EDA Manuals") #:icon "help-browser"
+     #:tooltip (_ "View the front page of the Lepton EDA documentation in a browser."))
   (show-wiki "geda:documentation"))
 
 
 (define-action-public
-    (&help-guide #:label (_ "gschem User Guide") #:icon "gtk-help"
-                 #:tooltip (_ "View the gschem User Guide in a browser."))
+    (&help-guide #:label (_ "lepton-schematic User Guide") #:icon "gtk-help"
+                 #:tooltip (_ "View the lepton-schematic User Guide in a browser."))
   (show-wiki "geda:gschem_ug"))
 
 
 (define-action-public
-    (&help-faq #:label (_ "gschem FAQ") #:icon "help-faq"
-     #:tooltip (_ "Frequently Asked Questions about using gschem."))
+    (&help-faq #:label (_ "lepton-schematic FAQ") #:icon "help-faq"
+     #:tooltip (_ "Frequently Asked Questions about using lepton-schematic."))
   (show-wiki "geda:faq-gschem"))
 
 
 (define-action-public
-    (&help-wiki #:label (_ "gEDA wiki") #:icon "web-browser"
-     #:tooltip (_ "View the front page of the gEDA wiki in a browser."))
+    (&help-wiki #:label (_ "Lepton EDA wiki") #:icon "web-browser"
+     #:tooltip (_ "View the front page of the Lepton EDA wiki in a browser."))
   (show-wiki))
 
 
-(define-action-public (&help-about #:label (_ "About gschem") #:icon "gtk-about")
+(define-action-public (&help-about #:label (_ "About lepton-schematic") #:icon "gtk-about")
   (%help-about))
 
 
