@@ -2,7 +2,7 @@
 ;; Scheme API
 ;; Copyright (C) 2011-2014 Peter Brett <peter@peter-b.co.uk>
 ;; Copyright (C) 2011-2015 gEDA Contributors
-;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;; Copyright (C) 2017-2019 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -27,45 +27,60 @@
   #:use-module (gschem util)
   #:use-module (ice-9 optargs)
   #:use-module (ice-9 regex)
-  #:use-module (srfi srfi-1))
+  #:use-module (srfi srfi-1)
+  #:export (sys-doc-dir)
+  #:export (user-doc-dir)
+  #:export (show-wiki)
+  #:export (show-component-documentation))
 
-;; FIXME this should probably be set via configure
-(define %configured-sys-doc-dir #f)
 
-(define-public (sys-doc-dir)
+
+; private:
+;
+; Call (gschem util)::show-uri( url ), catching exceptions.
+; Display message box on error.
+;
+( define ( doc-show-uri url )
+
+  ( catch
+    #t
+    ( lambda()
+      ( show-uri url )
+    )
+    ( lambda ( key subr msg args . rest )
+      ( let*
+      (
+      ( str   (_ "Could not show documentation:") )
+      ( exmsg ( apply format #f msg args ) )
+      ( ermsg ( format #f "~a~%'~a in ~a():~%~%~a" str key subr exmsg ) )
+      )
+        ( (@@ (guile-user) gschem-msg) ermsg )
+      )
+    )
+  ) ; catch()
+
+) ; doc-show-uri()
+
+
+
+; private:
+;
+( define ( doc-show-file fpath )
+  ; return:
+  ( doc-show-uri (format #f "file://~a" fpath) )
+)
+
+
+
+(define (sys-doc-dir)
   "sys-doc-dir
 
 Get the directory where gEDA documentation is stored."
 
-  ;; Given a gEDA data directory path, guess the installation prefix.
-  (define (guess-prefix dir)
-    (let ((ofs (string-contains
-                dir (string-append file-name-separator-string "share"))))
-      (and ofs (substring dir 0 ofs))))
+  "/usr/local/share/doc/lepton-eda"
+)
 
-  ;; Guess the gEDA documentation directory, using the gEDA data
-  ;; search path.  Guaranteed to only return paths that correspond to
-  ;; actual directories.
-  (define (guess-docdir)
-    (any
-
-     (lambda (dir)
-       (let ((docdir
-              (string-join (list dir
-                                 "share" "doc" "lepton-eda")
-                           file-name-separator-string)))
-         (and (false-if-exception
-               (eq? 'directory (stat:type (stat docdir))))
-              docdir)))
-
-     (filter-map guess-prefix (sys-data-dirs))))
-
-  (or (guess-docdir)
-      (if (platform? 'win32-native)
-          #f
-          %configured-sys-doc-dir)))
-
-(define-public (user-doc-dir)
+(define (user-doc-dir)
   "user-doc-dir
 
 Get the directory where per-user gEDA documentation is stored."
@@ -84,7 +99,7 @@ Get the directory where per-user gEDA documentation is stored."
        (else c)))
    name))
 
-(define*-public (show-wiki #:optional (page "index"))
+(define* (show-wiki #:optional (page "index"))
   "show-wiki PAGE
 
 Launch a browser to display a page from the offline version of the
@@ -92,7 +107,7 @@ gEDA wiki shipped with gEDA/gaf.  The specified PAGE should be a
 string containing the page name as used on the live version of the
 wiki."
 
-  (show-uri
+  (doc-show-uri
    (string-append "file://"
                   (string-join (list (sys-doc-dir) "wiki")
                                file-name-separator-string 'suffix)
@@ -143,14 +158,14 @@ wiki."
            (file-exists? filename)
            filename)))
   (let ((filename (false-if-exception (directory-any dirname test-dir-entry))))
-    (and filename (begin (show-file filename) #t))))
+    (and filename (begin (doc-show-file filename) #t))))
 
 ;; Searches for documentation STRING on the Internet, using
 ;; %pdf-search-template.
 ;;
 ;; FIXME string should be URL-encoded.
 (define (internet-doc-search string)
-  (show-uri (format #f %pdf-search-template string)) #t)
+  (doc-show-uri (format #f %pdf-search-template string)) #t)
 
 ;; Munges a component basename to look more like a device name
 (define (munge-basename basename)
@@ -160,7 +175,7 @@ wiki."
         (regexp-substitute #f match 'pre)
         basename)))
 
-(define-public (show-component-documentation obj)
+(define (show-component-documentation obj)
   "show-component-documentation COMPONENT
 
 Find the documentation for COMPONENT, by inspecting (in order) its
@@ -193,7 +208,7 @@ displayed in the system associated viewer application."
        ;; c) Does the documentation attribute look like a URL?
        (and (any (lambda (prefix) (string-prefix? prefix documentation))
                  '("http://" "ftp://" "file://"))
-            (show-uri documentation))
+            (doc-show-uri documentation))
 
        ;; d) If a documentation attribute was specified at all, search
        ;;    for it with Google.
