@@ -2,7 +2,7 @@
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ g_rc_parse_gtkrc(void)
 
 	/* Search for the first gschem-gtkrc file in the system
 	 * configuration path. */
-	const gchar * const * sys_dirs = g_get_system_config_dirs();
+	const gchar * const * sys_dirs = eda_get_system_config_dirs();
 	for (gint i = 0; sys_dirs[i]; ++i) {
 		filename = g_build_filename (sys_dirs[i], "gschem-gtkrc", NULL);
 		if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
@@ -290,24 +290,6 @@ SCM g_rc_snap_size(SCM size)
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_logging_destination(SCM mode)
-{
-  static const vstbl_entry mode_table[] = {
-    {LOG_WINDOW         , "log_window" },
-    {STDOUT_TTY         , "tty"        },
-    {BOTH_LOGWIN_STDOUT , "both"       }
-  };
-
-  RETURN_G_RC_MODE("logging-destination",
-		   logging_dest,
-		   3);
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -352,40 +334,6 @@ SCM g_rc_scrollbars(SCM mode)
 		   2);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_image_color(SCM mode)
-{
-  static const vstbl_entry mode_table[] = {
-    {TRUE , "enabled" },
-    {FALSE, "disabled"},
-  };
-
-  RETURN_G_RC_MODE("image-color",
-		   default_image_color,
-		   2);
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_image_size(SCM width, SCM height)
-{
-  SCM_ASSERT (scm_is_integer (width),  width,  SCM_ARG1, "image-size");
-  SCM_ASSERT (scm_is_integer (height), height, SCM_ARG2, "image-size");
-
-  /* yes this is legit, we are casting the resulting double to an int */
-  default_image_width  = scm_to_int (width);
-  default_image_height = scm_to_int (height);
-
-  return SCM_BOOL_T;
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -403,23 +351,6 @@ SCM g_rc_log_window(SCM mode)
 		   2);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_log_window_type(SCM mode)
-{
-  static const vstbl_entry mode_table[] = {
-    {TRANSIENT, "transient" },
-    {DECORATED, "decorated" },
-  };
-
-  RETURN_G_RC_MODE("log-window-type",
-		   default_log_window_type,
-		   2);
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -428,13 +359,26 @@ SCM g_rc_log_window_type(SCM mode)
 SCM g_rc_third_button(SCM mode)
 {
   static const vstbl_entry mode_table[] = {
-    {POPUP_ENABLED   , "popup"   },
-    {MOUSEPAN_ENABLED, "mousepan"},
+    {MOUSEBTN_DO_POPUP, "popup"   },
+    {MOUSEBTN_DO_PAN,   "mousepan"},
   };
 
+  const int table_size = sizeof (mode_table) / sizeof (mode_table[0]);
+
+  if (scm_is_eq (mode, SCM_UNDEFINED))
+  {
+    for (int i = 0; i < table_size; ++i)
+    {
+      if (default_third_button == mode_table[i].m_val)
+        return scm_from_utf8_string (mode_table[i].m_str);
+    }
+
+    return scm_from_utf8_string ("none");
+  }
+
   RETURN_G_RC_MODE("third-button",
 		   default_third_button,
-		   2);
+		   table_size);
 }
 
 /*! \brief Verify if the third button cancel mode is set in the RC
@@ -471,16 +415,29 @@ SCM g_rc_third_button_cancel(SCM mode)
 SCM g_rc_middle_button(SCM mode)
 {
   static const vstbl_entry mode_table[] = {
-    {STROKE, "stroke"},
-    {REPEAT, "repeat"},
-    {ACTION, "action"},
-    {MID_MOUSEPAN_ENABLED, "mousepan"},
-    {POPUP_ENABLED,        "popup"   },
+    {MOUSEBTN_DO_STROKE, "stroke"},
+    {MOUSEBTN_DO_REPEAT, "repeat"},
+    {MOUSEBTN_DO_ACTION, "action"},
+    {MOUSEBTN_DO_PAN,    "mousepan"},
+    {MOUSEBTN_DO_POPUP,  "popup"},
   };
 
+  const int table_size = sizeof (mode_table) / sizeof (mode_table[0]);
+
+  if (scm_is_eq (mode, SCM_UNDEFINED))
+  {
+    for (int i = 0; i < table_size; ++i)
+    {
+      if (default_middle_button == mode_table[i].m_val)
+        return scm_from_utf8_string (mode_table[i].m_str);
+    }
+
+    return scm_from_utf8_string ("none");
+  }
+
   RETURN_G_RC_MODE("middle-button",
 		   default_middle_button,
-		   5);
+		   table_size);
 }
 
 /*! \todo Finish function documentation!!!
@@ -569,23 +526,6 @@ SCM g_rc_fast_mousepan(SCM mode)
 		   2);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_raise_dialog_boxes_on_expose(SCM mode)
-{
-  static const vstbl_entry mode_table[] = {
-    {TRUE , "enabled" },
-    {FALSE, "disabled"},
-  };
-
-  RETURN_G_RC_MODE("raise-dialog-boxes-on-expose",
-		   default_raise_dialog_boxes,
-		   2);
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -747,22 +687,6 @@ SCM g_rc_add_menu(SCM scm_menu_name, SCM scm_menu_items)
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_window_size(SCM width, SCM height)
-{
-  SCM_ASSERT (scm_is_integer (width),  width,  SCM_ARG1, "window-size");
-  SCM_ASSERT (scm_is_integer (height), height, SCM_ARG2, "window-size");
-
-  default_width  = scm_to_int (width);
-  default_height = scm_to_int (height);
-
-  return SCM_BOOL_T;
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -1005,31 +929,6 @@ SCM g_rc_mesh_grid_display_threshold (SCM spacing)
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_add_attribute_offset(SCM offset)
-{
-  int val;
-
-  SCM_ASSERT (scm_is_integer (offset), offset,
-              SCM_ARG1, "add-attribute-offset");
-
-  val = scm_to_int (offset);
-
-  if (val < 0) {
-    fprintf(stderr, _("Invalid offset [%1$d] passed to add-attribute-offset\n"),
-            val);
-    val = 50; /* absolute default */
-  }
-
-  default_add_attribute_offset = val;
-
-  return SCM_BOOL_T;
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
