@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,20 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
+
 #include <config.h>
-
-#include <stdio.h>
-#include <sys/stat.h>
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
-#ifdef HAVE_ASSERT_H
-#include <assert.h>
-#endif
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
 #include "gschem.h"
 
 /*! \brief */
@@ -61,23 +49,18 @@ static struct gsubr_t gschem_funcs[] = {
   { "snap-size",                    1, 0, 0, (SCM (*) ()) g_rc_snap_size },
 
   { "text-caps-style",              1, 0, 0, (SCM (*) ()) g_rc_text_caps_style },
-  { "logging-destination",          1, 0, 0, (SCM (*) ()) g_rc_logging_destination },
 
   { "attribute-name",               1, 0, 0, (SCM (*) ()) g_rc_attribute_name },
 
-  { "image-color",                  1, 0, 0, (SCM (*) ()) g_rc_image_color },
-  { "image-size",                   2, 0, 0, (SCM (*) ()) g_rc_image_size },
   { "log-window",                   1, 0, 0, (SCM (*) ()) g_rc_log_window },
-  { "log-window-type",              1, 0, 0, (SCM (*) ()) g_rc_log_window_type },
-  { "third-button",                 1, 0, 0, (SCM (*) ()) g_rc_third_button },
+  { "third-button",                 0, 1, 0, (SCM (*) ()) g_rc_third_button },
   { "third-button-cancel",          1, 0, 0, (SCM (*) ()) g_rc_third_button_cancel },
-  { "middle-button",                1, 0, 0, (SCM (*) ()) g_rc_middle_button },
+  { "middle-button",                0, 1, 0, (SCM (*) ()) g_rc_middle_button },
   { "scroll-wheel",                 1, 0, 0, (SCM (*) ()) g_rc_scroll_wheel },
   { "net-consolidate",              1, 0, 0, (SCM (*) ()) g_rc_net_consolidate },
   { "file-preview",                 1, 0, 0, (SCM (*) ()) g_rc_file_preview },
   { "enforce-hierarchy",            1, 0, 0, (SCM (*) ()) g_rc_enforce_hierarchy },
   { "fast-mousepan",                1, 0, 0, (SCM (*) ()) g_rc_fast_mousepan },
-  { "raise-dialog-boxes-on-expose", 1, 0, 0, (SCM (*) ()) g_rc_raise_dialog_boxes_on_expose },
   { "continue-component-place",     1, 0, 0, (SCM (*) ()) g_rc_continue_component_place },
   { "undo-levels",                  1, 0, 0, (SCM (*) ()) g_rc_undo_levels },
   { "undo-control",                 1, 0, 0, (SCM (*) ()) g_rc_undo_control },
@@ -88,7 +71,6 @@ static struct gsubr_t gschem_funcs[] = {
   { "netconn-rubberband",           1, 0, 0, (SCM (*) ()) g_rc_netconn_rubberband },
   { "magnetic-net-mode",            1, 0, 0, (SCM (*) ()) g_rc_magnetic_net_mode },
   { "add-menu",                     2, 0, 0, (SCM (*) ()) g_rc_add_menu },
-  { "window-size",                  2, 0, 0, (SCM (*) ()) g_rc_window_size },
   { "warp-cursor",                  1, 0, 0, (SCM (*) ()) g_rc_warp_cursor },
   { "toolbars",                     1, 0, 0, (SCM (*) ()) g_rc_toolbars },
   { "handleboxes",                  1, 0, 0, (SCM (*) ()) g_rc_handleboxes },
@@ -101,7 +83,6 @@ static struct gsubr_t gschem_funcs[] = {
   { "dots-grid-mode",               1, 0, 0, (SCM (*) ()) g_rc_dots_grid_mode },
   { "dots-grid-fixed-threshold",    1, 0, 0, (SCM (*) ()) g_rc_dots_grid_fixed_threshold },
   { "mesh-grid-display-threshold",  1, 0, 0, (SCM (*) ()) g_rc_mesh_grid_display_threshold },
-  { "add-attribute-offset",         1, 0, 0, (SCM (*) ()) g_rc_add_attribute_offset },
   { "mousepan-gain",                1, 0, 0, (SCM (*) ()) g_rc_mousepan_gain },
   { "keyboardpan-gain",             1, 0, 0, (SCM (*) ()) g_rc_keyboardpan_gain },
   { "select-slack-pixels",          1, 0, 0, (SCM (*) ()) g_rc_select_slack_pixels },
@@ -112,9 +93,6 @@ static struct gsubr_t gschem_funcs[] = {
   { "auto-save-interval",           1, 0, 0, (SCM (*) ()) g_rc_auto_save_interval },
 
   /* general guile functions */
-  { "gschem-pdf",                   1, 0, 0, (SCM (*) ()) g_funcs_pdf },
-  { "gschem-image",                 1, 0, 0, (SCM (*) ()) g_funcs_image },
-  { "gschem-use-rc-values",         0, 0, 0, (SCM (*) ()) g_funcs_use_rc_values },
   { "gschem-exit",                  0, 0, 0, (SCM (*) ()) g_funcs_exit },
   { "gschem-log",                   1, 0, 0, (SCM (*) ()) g_funcs_log },
   { "gschem-msg",                   1, 0, 0, (SCM (*) ()) g_funcs_msg },
@@ -222,8 +200,6 @@ static struct gsubr_t gschem_funcs[] = {
   { "hierarchy-down-schematic",     0, 0, 0, (SCM (*) ()) g_keys_hierarchy_down_schematic },
   { "hierarchy-down-symbol",        0, 0, 0, (SCM (*) ()) g_keys_hierarchy_down_symbol },
   { "hierarchy-up",                 0, 0, 0, (SCM (*) ()) g_keys_hierarchy_up },
-  { "attributes-attach",            0, 0, 0, (SCM (*) ()) g_keys_attributes_attach },
-  { "attributes-detach",            0, 0, 0, (SCM (*) ()) g_keys_attributes_detach },
   { "attributes-show-name",         0, 0, 0, (SCM (*) ()) g_keys_attributes_show_name },
   { "attributes-show-value",        0, 0, 0, (SCM (*) ()) g_keys_attributes_show_value },
   { "attributes-show-both",         0, 0, 0, (SCM (*) ()) g_keys_attributes_show_both },
