@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -198,6 +198,9 @@ GschemToplevel *gschem_toplevel_new ()
   /* font selection widget: */
   w_current->font_select_widget = NULL;
 
+  /* page selection widget: */
+  w_current->page_select_widget = NULL;
+
   /* dialogs for widgets */
   w_current->options_widget_dialog    = NULL;
   w_current->text_properties_dialog   = NULL;
@@ -206,6 +209,7 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->find_text_state_dialog   = NULL;
   w_current->color_edit_dialog        = NULL;
   w_current->font_select_dialog       = NULL;
+  w_current->page_select_dialog       = NULL;
 
 
   w_current->keyaccel_string = NULL;
@@ -217,7 +221,6 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->sowindow     = NULL;
   w_current->pfswindow    = NULL;
   w_current->cswindow     = NULL;
-  w_current->pswindow     = NULL;
   w_current->tiwindow     = NULL;
   w_current->sewindow     = NULL;
   w_current->aawindow     = NULL;
@@ -289,8 +292,6 @@ GschemToplevel *gschem_toplevel_new ()
   /* --------------------- */
   w_current->num_untitled = 0;
   w_current->event_state = SELECT;
-  w_current->image_width  = 0;
-  w_current->image_height = 0;
   w_current->min_zoom = 0;
   w_current->max_zoom = 8;
   w_current->drawbounding_action_mode = FREE;
@@ -299,7 +300,6 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->SHIFTKEY   = 0;
   w_current->ALTKEY     = 0;
   w_current->buffer_number = 0;
-  w_current->last_callback = NULL;
   w_current->clipboard_buffer = NULL;
 
   /* ------------------ */
@@ -324,14 +324,12 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->include_complex = 0;
   w_current->scrollbars_flag = 0;
   w_current->log_window = 0;
-  w_current->log_window_type = 0;
   w_current->third_button = 0;
   w_current->third_button_cancel = TRUE;
   w_current->middle_button = 0;
   w_current->file_preview = 0;
   w_current->enforce_hierarchy = 0;
   w_current->fast_mousepan = 0;
-  w_current->raise_dialog_boxes = 0;
   w_current->continue_component_place = 0;
   w_current->undo_levels = 0;
   w_current->undo_control = 0;
@@ -349,7 +347,6 @@ GschemToplevel *gschem_toplevel_new ()
   w_current->dots_grid_dot_size = 1;
   w_current->dots_grid_mode = DOTS_GRID_VARIABLE_MODE;
   w_current->mesh_grid_display_threshold = 3;
-  w_current->add_attribute_offset = 50;
   w_current->mousepan_gain = 5;
   w_current->keyboardpan_gain = 10;
   w_current->select_slack_pixels = 4;
@@ -695,7 +692,7 @@ gschem_toplevel_page_content_changed (GschemToplevel *w_current, PAGE *page)
 
   page->CHANGED = 1;
 
-  x_pagesel_update (w_current);
+  page_select_widget_update (w_current);
 }
 
 
