@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -259,79 +260,6 @@ void i_set_state_msg(GschemToplevel *w_current, enum x_states newstate,
   i_show_state(w_current, message);
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-void i_update_middle_button (GschemToplevel *w_current,
-                             i_callback_func func_ptr,
-                             const char *string)
-{
-  g_return_if_fail (w_current != NULL);
-  g_return_if_fail (w_current->bottom_widget != NULL);
-
-  switch(w_current->middle_button) {
-
-    /* remove this case eventually and make it a null case */
-    case(ACTION):
-      gschem_bottom_widget_set_middle_button_text (
-          GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-          _("Action"));
-      w_current->last_callback = NULL;
-      break;
-
-#ifdef HAVE_LIBSTROKE
-    case(STROKE):
-      gschem_bottom_widget_set_middle_button_text (
-          GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-          _("Stroke"));
-      w_current->last_callback = NULL;
-    break;
-#else
-    /* remove this case eventually and make it a null case */
-    case(STROKE):
-      gschem_bottom_widget_set_middle_button_text (
-          GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-          _("none"));
-      w_current->last_callback = NULL;
-      break;
-#endif
-
-    case(REPEAT):
-      if ((string != NULL) && (func_ptr != NULL))
-      {
-        char *temp_string = g_strconcat (_("Repeat/"), string, NULL);
-
-        gschem_bottom_widget_set_middle_button_text (
-            GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-            temp_string);
-
-        g_free(temp_string);
-        w_current->last_callback = func_ptr;
-      } else {
-        gschem_bottom_widget_set_middle_button_text (
-            GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-            _("Repeat/none"));
-        w_current->last_callback = NULL;
-      }
-      break;
-
-    case(MID_MOUSEPAN_ENABLED):
-      gschem_bottom_widget_set_middle_button_text (
-          GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-          _("Pan"));
-      w_current->last_callback = NULL;
-      break;
-
-    default:
-      gschem_bottom_widget_set_middle_button_text (
-          GSCHEM_BOTTOM_WIDGET (w_current->bottom_widget),
-          _("none"));
-      w_current->last_callback = NULL;
-  }
-}
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \param [in] w_current GschemToplevel structure
@@ -395,6 +323,10 @@ static void clipboard_usable_cb (int usable, void *userdata)
   x_menus_sensitivity (w_current, "_Edit/_Paste", usable);
 }
 
+
+
+/*! \brief Return TRUE if at least 1 text object is selected
+ */
 static gboolean
 selected_at_least_one_text_object(GschemToplevel *w_current)
 {
@@ -412,6 +344,31 @@ selected_at_least_one_text_object(GschemToplevel *w_current)
 }
 
 
+
+/*! \brief Return TRUE if at least 1 component object is selected
+ */
+static gboolean
+selected_at_least_one_comp_object(GschemToplevel *w_current)
+{
+  gboolean result = FALSE;
+  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
+  GList* selected = geda_list_get_glist (toplevel->page_current->selection_list);
+
+  for ( ; selected != NULL; selected = g_list_next (selected) )
+  {
+    OBJECT* obj = (OBJECT*) selected->data;
+    if (obj->complex != NULL)
+    {
+      result = TRUE;
+      break;
+    }
+  }
+
+  return result;
+}
+
+
+
 /*! \brief Update sensitivity of relevant menu items
  *
  *  \par Function Description
@@ -421,7 +378,8 @@ selected_at_least_one_text_object(GschemToplevel *w_current)
  */
 void i_update_menus(GschemToplevel *w_current)
 {
-  gboolean have_text_selected;
+  gboolean have_text_selected = FALSE;
+  gboolean have_comp_selected = FALSE;
   TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
   /*
    * This is very simplistic.  Right now it just disables all menu
@@ -437,6 +395,7 @@ void i_update_menus(GschemToplevel *w_current)
 
   if (o_select_selected (w_current)) {
     have_text_selected = selected_at_least_one_text_object(w_current);
+    have_comp_selected = selected_at_least_one_comp_object(w_current);
 
     /* since one or more things are selected, we set these TRUE */
     /* These strings should NOT be internationalized */
@@ -457,7 +416,8 @@ void i_update_menus(GschemToplevel *w_current)
     x_menus_sensitivity(w_current, "_Edit/Update Component", TRUE);
     x_menus_sensitivity(w_current, "Hie_rarchy/_Down Schematic", TRUE);
     x_menus_sensitivity(w_current, "Hie_rarchy/Down _Symbol", TRUE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/D_ocumentation...", TRUE);
+    x_menus_sensitivity(w_current, "_Help/Find Component D_ocumentation",
+                        have_comp_selected);
     x_menus_sensitivity(w_current, "A_ttributes/_Attach", TRUE);
     x_menus_sensitivity(w_current, "A_ttributes/_Detach", TRUE);
     x_menus_sensitivity(w_current, "A_ttributes/Show _Value", have_text_selected);
@@ -490,7 +450,7 @@ void i_update_menus(GschemToplevel *w_current)
     x_menus_sensitivity(w_current, "_Edit/Update Component", FALSE);
     x_menus_sensitivity(w_current, "Hie_rarchy/_Down Schematic", FALSE);
     x_menus_sensitivity(w_current, "Hie_rarchy/Down _Symbol", FALSE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/D_ocumentation...", FALSE);
+    x_menus_sensitivity(w_current, "_Help/Find Component D_ocumentation", FALSE);
     x_menus_sensitivity(w_current, "A_ttributes/_Attach", FALSE);
     x_menus_sensitivity(w_current, "A_ttributes/_Detach", FALSE);
     x_menus_sensitivity(w_current, "A_ttributes/Show _Value", FALSE);
@@ -507,35 +467,63 @@ void i_update_menus(GschemToplevel *w_current)
 
 }
 
-/*! \brief Set filename as gschem window title
+/*! \brief Set the main window's title
  *
  *  \par Function Description
- *  Set filename as gschem window title using
- *  the gnome HID format style.
+ *  Set the main window's title using \a filename.
+ *  Prepend an asterisk ("*") to indicate that the page
+ *  is modified if \a changed is TRUE.
+ *  Depending on [schematic.gui]::title-show-path configuration
+ *  value, either full path or basename of \a filename is shown
+ *  in the title.
  *
  *  \param [in] w_current GschemToplevel structure
- *  \param [in] string The filename
- *  \param [in] string 'Page changed' indication in window's title
+ *  \param [in] filename  The filename
+ *  \param [in] changed   Page changed status
  */
-void i_set_filename(GschemToplevel *w_current, const gchar *string, const gchar *changed)
+void i_set_filename (GschemToplevel* w_current,
+                     const gchar* filename,
+                     gboolean changed)
 {
-  gchar *print_string=NULL;
-  gchar *filename=NULL;
+  g_return_if_fail (w_current != NULL);
+  g_return_if_fail (w_current->main_window != NULL);
+  g_return_if_fail (filename);
 
-  if (!w_current->main_window)
-    return;
-  if (string == NULL)
-    return;
+  gchar* cwd = g_get_current_dir();
+  EdaConfig* cfg = eda_config_get_context_for_path (cwd);
+  g_free (cwd);
 
-  filename = g_path_get_basename(string);
+  gboolean show_fullpath = FALSE;
 
-  print_string = g_strdup_printf("%s%s - lepton-schematic", changed, filename);
+  if (cfg != NULL)
+  {
+    GError*  err = NULL;
+    gboolean val = eda_config_get_boolean (cfg,
+                                           "schematic.gui",
+                                           "title-show-path",
+                                           &err);
+    if (err == NULL)
+    {
+      show_fullpath = val;
+    }
 
-  gtk_window_set_title(GTK_WINDOW(w_current->main_window),
-		       print_string);
+    g_clear_error (&err);
+  }
 
-  g_free(print_string);
-  g_free(filename);
+
+  gchar* fname = show_fullpath
+                 ? g_strdup (filename)
+                 : g_path_get_basename (filename);
+
+  gchar* title = g_strdup_printf ("%s%s - lepton-schematic",
+                                  changed ? "* " : "",
+                                  fname);
+
+  gtk_window_set_title (GTK_WINDOW (w_current->main_window),
+                        title);
+
+  g_free (title);
+  g_free (fname);
 }
 
 /*! \brief Write the grid settings to the gschem status bar
