@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2012 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 #include "gschem.h"
 
-#define GETOPT_OPTIONS "c:hL:o:pqs:vV"
+#define GETOPT_OPTIONS "c:hL:qs:vV"
 
 extern char *optarg;
 extern int optind;
@@ -44,14 +44,10 @@ struct option long_options[] =
     {"version", 0, 0, 'V'},
     {"quiet", 0, 0, 'q'},
     {"verbose", 0, 0, 'v'},
-    {"output", 0, 0, 'o'},
     {0, 0, 0, 0}
   };
 #endif
 
-/*! Contains an output filename for Scheme export functions */
-SCM output_filename_s = SCM_BOOL_F;
-
 /*! Contains a Scheme expression arising from command-line arguments.
  *  This is evaluated after initialising gschem, but before loading
  *  any rc files. */
@@ -76,9 +72,9 @@ usage(char *cmd)
   printf(_(
 "Usage: %1$s [OPTION ...] [--] [FILE ...]\n"
 "\n"
-"Interactively edit gEDA schematics or symbols.  If one or more FILEs\n"
-"are specified, open them for editing; otherwise, create a new, empty\n"
-"schematic.\n"
+"Interactively edit Lepton EDA schematics or symbols.\n"
+"If one or more FILEs are specified, open them for\n"
+"editing; otherwise, create a new, empty schematic.\n"
 "\n"
 "Options:\n"
 "  -q, --quiet              Quiet mode.\n"
@@ -86,14 +82,12 @@ usage(char *cmd)
 "  -L DIR                   Add DIR to Scheme search path.\n"
 "  -c EXPR                  Scheme expression to run at startup.\n"
 "  -s FILE                  Scheme script to run at startup.\n"
-"  -o, --output=FILE        Output filename (for printing).\n"
-"  -p                       Automatically place the window.\n"
 "  -V, --version            Show version information.\n"
 "  -h, --help               Help; this message.\n"
 "  --                       Treat all remaining arguments as filenames.\n"
 "\n"
 "Report bugs at <https://github.com/lepton-eda/lepton-eda/issues>\n"
-"gEDA/gaf homepage: <http://www.geda-project.org/>\n"),
+"Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>\n"),
          cmd);
   exit(0);
 }
@@ -109,7 +103,7 @@ version ()
   printf(_(
 "Lepton EDA %1$s (git: %2$.7s)\n"
 "Copyright (C) 1998-2017 by Ales Hvezda and the respective original authors.\n"
-"Copyright (C) 2017-2018 Lepton Developers.\n"
+"Copyright (C) 2017-2019 Lepton Developers.\n"
 "This is free software, and you are welcome to redistribute it under\n"
 "certain conditions. For details, see the file `COPYING', which is\n"
 "included in the Lepton EDA distribution.\n"
@@ -173,14 +167,6 @@ parse_commandline(int argc, char *argv[])
                     s_post_load_expr);
         break;
 
-      case 'o':
-        output_filename_s = scm_from_locale_string (optarg);
-        break;
-
-      case 'p':
-        auto_place_mode = TRUE;
-        break;
-
       case 'L':
         /* Argument is a directory to add to the Scheme load path.
          * Add the necessary expression to be evaluated before rc file
