@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,27 +52,6 @@ x_event_expose(GschemPageView *view, GdkEventExpose *event, GschemToplevel *w_cu
 
 
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-gint
-x_event_raise_dialog_boxes (GschemPageView *view, GdkEventExpose *event, GschemToplevel *w_current)
-{
-  g_return_val_if_fail (w_current != NULL, 0);
-
-  /* raise the dialog boxes if this feature is enabled */
-  if (w_current->raise_dialog_boxes) {
-    x_dialog_raise_all(w_current);
-  }
-
-  return 0;
-}
-
-
-
-
 /*! \todo Finish function documentation!!!
  *  \brief
  *  \par Function Description
@@ -214,7 +193,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
 
     switch(w_current->middle_button) {
 
-      case(ACTION):
+      case(MOUSEBTN_DO_ACTION):
 
       /* don't want to search if shift */
       /* key is pressed */
@@ -240,36 +219,33 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
       }
       break;
 
-      case(REPEAT):
-      if (w_current->last_callback != NULL) {
-        (*w_current->last_callback)(w_current, 0, NULL);
-      }
+      case(MOUSEBTN_DO_REPEAT):
+        g_scm_c_eval_string_protected
+        (
+          "( use-modules (gschem action) )"
+          "( &repeat-last-action )"
+        );
       break;
 #ifdef HAVE_LIBSTROKE
-      case(STROKE):
+      case(MOUSEBTN_DO_STROKE):
       DOING_STROKE=TRUE;
       break;
 #endif /* HAVE_LIBSTROKE */
 
-      case(MID_MOUSEPAN_ENABLED):
+      case(MOUSEBTN_DO_PAN):
       gschem_page_view_pan_start (page_view, (int) event->x, (int) event->y);
       break;
-    }
 
-
-    if (!w_current->inside_action)
-    {
-      if (w_current->middle_button == POPUP_ENABLED)
-      {
-        i_update_menus(w_current);  /* update menus before popup  */
+      case (MOUSEBTN_DO_POPUP):
+        i_update_menus(w_current);
         do_popup(w_current, event);
-      }
-    }
+        break;
 
+    } /* switch w_current->middle_button */
 
   } else if (event->button == 3) {
     if (!w_current->inside_action) {
-      if (w_current->third_button == POPUP_ENABLED) {
+      if (w_current->third_button == MOUSEBTN_DO_POPUP) {
         /* (third-button "popup") */
         i_update_menus(w_current);  /* update menus before popup  */
         do_popup(w_current, event);
@@ -278,7 +254,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
         gschem_page_view_pan_start (page_view, (int) event->x, (int) event->y);
       }
     } else {
-      if ((w_current->third_button == MOUSEPAN_ENABLED) &&
+      if ((w_current->third_button == MOUSEBTN_DO_PAN) &&
           (!w_current->third_button_cancel)) {
         gschem_page_view_pan_start (page_view, (int) event->x, (int) event->y);
       } else { /* this is the default cancel */
@@ -404,7 +380,7 @@ x_event_button_released (GschemPageView *page_view, GdkEventButton *event, Gsche
     }
 
     switch(w_current->middle_button) {
-      case(ACTION):
+      case(MOUSEBTN_DO_ACTION):
         if (w_current->inside_action && (page->place_list != NULL)) {
           switch(w_current->event_state) {
             case (COPYMODE): o_copy_end(w_current); break;
@@ -414,13 +390,13 @@ x_event_button_released (GschemPageView *page_view, GdkEventButton *event, Gsche
       break;
 
 #ifdef HAVE_LIBSTROKE
-      case(STROKE):
+      case(MOUSEBTN_DO_STROKE):
       DOING_STROKE = FALSE;
       x_stroke_translate_and_execute (w_current);
       break;
 #endif /* HAVE_LIBSTROKE */
 
-      case(MID_MOUSEPAN_ENABLED):
+      case(MOUSEBTN_DO_PAN):
         if (gschem_page_view_pan_end (page_view) && w_current->undo_panzoom) {
           o_undo_savestate_old(w_current, UNDO_VIEWPORT_ONLY);
         }
