@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,12 +30,11 @@
 
 #define DEFAULT_MAX_RECENT_FILES 10
 
-struct PopupEntry {
-  #ifdef __cplusplus
-  const gchar *name, *action, *stock_id;
-  #else
-  const gchar const *name, *action, *stock_id;
-  #endif
+struct PopupEntry
+{
+  const gchar* name;
+  const gchar* action;
+  const gchar* stock_id;
 };
 
 static struct PopupEntry popup_items[] = {
@@ -131,10 +130,28 @@ get_main_menu(GschemToplevel *w_current)
     gtk_widget_show(menu_item);
 
     scm_items_len = (int) scm_ilength (scm_items);
-    for (j = 0 ; j < scm_items_len; j++) {
 
+
+    /* cycle through menu items:
+    */
+    for (j = 0 ; j < scm_items_len; j++)
+    {
       scm_index = scm_from_int (j);
+
+      /* menu item:
+      */
       scm_item = scm_list_ref (scm_items, scm_index);
+
+      /* check if [scm_item] is valid, it must be a
+       * ( list TEXT ACTION ICON ):
+      */
+      if ( scm_is_false (scm_list_p (scm_item)) )
+        continue;
+
+      if ( scm_to_int (scm_length (scm_item)) != 3 )
+        continue;
+
+
       scm_item_name = SCM_CAR (scm_item);
       scm_item_func = SCM_CADR (scm_item);
       scm_item_stock = scm_is_pair (SCM_CDDR (scm_item)) ?
