@@ -1,5 +1,6 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 2018 dmn <graahnul.grom@gmail.com>
+ * Copyright (C) 2018-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -728,9 +729,6 @@ x_tabs_pview_create (GschemToplevel* w_current,
   gtk_container_add (GTK_CONTAINER (wtab), GTK_WIDGET (pview));
   gtk_widget_show_all (wtab);
 
-  gtk_widget_set_size_request (GTK_WIDGET (pview),
-                               default_width, default_height);
-
   GTK_WIDGET_SET_FLAGS (pview, GTK_CAN_FOCUS);
 
   x_window_setup_draw_events_drawing_area (w_current, pview);
@@ -772,10 +770,11 @@ x_tabs_hdr_create (TabInfo* nfo)
   const gboolean show_btn_up    = x_tabs_show_up_button();
   const gboolean show_btn_close = x_tabs_show_close_button();
 
+
   /* label:
   */
   const gchar* fname = NULL;
-  gchar* bname = NULL;
+  gchar*       bname = NULL;
 
   if (nfo->page_)
     fname = s_page_get_filename (nfo->page_);
@@ -783,10 +782,19 @@ x_tabs_hdr_create (TabInfo* nfo)
   if (fname)
     bname = g_path_get_basename (fname);
 
-  GtkWidget* lab = gtk_label_new (bname);
+  gchar* lab_txt = NULL;
+
+  if (nfo->page_->CHANGED)
+    lab_txt = g_strdup_printf ("* <b>%s</b>", bname);
+  else
+    lab_txt = g_strdup (bname);
+
+  GtkWidget* lab = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (lab), lab_txt);
   gtk_box_pack_start (GTK_BOX (box_lab), lab, TRUE, TRUE, 0);
 
   g_free (bname);
+  g_free (lab_txt);
 
 
   /* tab's tooltip:
